#include <ESP8266WiFi.h>
#include <WiFiClient.h>
#include <ESP8266WebServer.h>
#include <ESP8266mDNS.h>

const char* ssid = "RWEMA Wfi";
const char* password = "rwema@0000";

ESP8266WebServer server(80);

/********************
 * Function to handle root/main page of the program
 * which is [IP address]/
*********************/
void handleRoot(){
  int magRead = analogRead(A0);
  Serial.println(magRead);
  String draw = "";  // This variable will hold the html code.
  draw += "<DOCTYPE html><html><head><meta http-equiv='refresh' content='1'/>";
  draw += "<title>Interface application and Programming</title></head>";
  draw += "<body><h1>Magnet plotter</h1><div><svg width=\"100%\" heigth=\"100\">";
  draw += "<rect x=\"100\" y=\"10\" width=\"1000\" height=\"70\" fill=\"red\"></rect>";
  draw += "<rect x=\"100\" y=\"10\" width=\"" + String(magRead) + "\"";
  draw += "height=\"70\" fill=\"blue\"></rect>";
  draw += "</svg></div></body></html>";

  server.send(200, "text/html", draw);  // Send the html code when this statement is called
}

/***************************
 * This function generate the 404 message
 * when the user is looking for unknown page
***************************/
void handleNotFound(){
  digitalWrite(led, 1);
  String message = "File Not Found\n\n";
  message += "URI: ";
  message += server.uri();
  message += "\nMethod: ";
  message += (server.method() == HTTP_GET)?"GET":"POST";
  message += "\nArguments: ";
  message += server.args();
  message += "\n";
  for (uint8_t i=0; i<server.args(); i++){
    message += " " + server.argName(i) + ": " + server.arg(i) + "\n";
  }
  server.send(404, "text/plain", message);
  digitalWrite(led, 0);
}

/**************************
 * This function initialize some peripheral
 * of the chip
**************************/
void setup(void){
  pinMode(led, OUTPUT);
  digitalWrite(led, 0);
  Serial.begin(115200);
  WiFi.mode(WIFI_STA);
  WiFi.begin(ssid, password);
  Serial.println("");

  // Wait for connection
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("");
  Serial.print("Connected to ");
  Serial.println(ssid);
  Serial.print("IP address: ");
  Serial.println(WiFi.localIP());

  if (MDNS.begin("esp8266")) {
    Serial.println("MDNS responder started");
  }

  server.on("/", handleRoot);

  server.on("/inline", [](){
    server.send(200, "text/plain", "this works as well");
  });

  server.onNotFound(handleNotFound);

  server.begin();
  Serial.println("HTTP server started");
}

/*************************
 * This is the main function of the program
 * it checks for the user/client request and
 * generate the appropriate page deppending on the request made
*************************/
void loop(void){
  server.handleClient();
}

